==> jspeed_0.1-2.tar.gz: jspeed-0.1/src/buttonselector.h <==
/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef BUTTONSELECTOR_H
#define BUTTONSELECTOR_H

#include <QtCore/QVariant>
#include <QtCore/QString>
#include <QtGui/QStandardItemModel>
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>

class ButtonSelector : public QMaemo5ValueButton
{

Q_OBJECT

public:
    ButtonSelector(QString const& text, QWidget* parent = 0);
    void addItem(QString const& text);
    void addItem(QString const& text, QVariant const& value);
    void clear();
    void setCurrentIndex(unsigned int index);
    int indexOfValue(QVariant const& value) const;
    bool selectByValue(QVariant const& value);
    int currentIndex() const;
    bool changeItem(unsigned int index, QString const& text);
    bool changeItem(unsigned int index, QString const& text, QVariant const& value);
    bool removeItem(unsigned int index);
    bool setValue(unsigned int index);
    QString text() const;
    QVariant value() const;

signals:
    void selected(unsigned int index, QString const& text, QVariant const& value);

private slots:
    void onSelected(QString const& text);

private:
    QMaemo5ListPickSelector* selector_;
    QStandardItemModel* model_;

};

#endif

==> jspeed_0.1-9.tar.gz: jspeed-0.1/src/buttonselector.h <==
/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef BUTTONSELECTOR_H
#define BUTTONSELECTOR_H

#include <QtCore/QVariant>
#include <QtCore/QString>
#include <QtGui/QStandardItemModel>
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>

class ButtonSelector : public QMaemo5ValueButton
{

Q_OBJECT

public:
    ButtonSelector(QString const& text, QWidget* parent = 0);
    void addItem(QString const& text);
    void addItem(QString const& text, QVariant const& value);
    void clear();
    void setCurrentIndex(unsigned int index);
    int indexOfValue(QVariant const& value) const;
    bool selectByValue(QVariant const& value);
    int currentIndex() const;
    int size() const;
    bool changeItem(unsigned int index, QString const& text);
    bool changeItem(unsigned int index, QString const& text, QVariant const& value);
    bool removeItem(unsigned int index);
    bool setValue(unsigned int index);
    QString text() const;
    QVariant value() const;

signals:
    void selected();

private slots:
    void onSelected(QString const& text);

private:
    QMaemo5ListPickSelector* selector_;
    QStandardItemModel* model_;

};

#endif
